Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppKeepers ¶
type AppKeepers struct {
AccountKeeper *authkeeper.AccountKeeper
ParamsKeeper *paramskeeper.Keeper
ConsensusParamsKeeper *consensusparamkeeper.Keeper
Codec codec.Codec
GetStoreKey func(storeKey string) *storetypes.KVStoreKey
CapabilityKeeper *capabilitykeeper.Keeper
IBCKeeper *ibckeeper.Keeper
EVMKeeper *evmkeeper.Keeper
Erc20Keeper *erc20keeper.Keeper
BankKeeper bankkeeper.BaseKeeper
// Module keepers
UExecutorKeeper *uexecutorkeeper.Keeper
URegistryKeeper *uregistrykeeper.Keeper
UValidatorKeeper *uvalidatorkeeper.Keeper
UTssKeeper *utsskeeper.Keeper
}
type ModuleManager ¶
type ModuleManager interface {
RunMigrations(ctx context.Context, cfg module.Configurator, fromVM module.VersionMap) (module.VersionMap, error)
GetVersionMap() module.VersionMap
}
type Upgrade ¶
type Upgrade struct {
// Upgrade version name, for the upgrade handler, e.g. `v7`
UpgradeName string
// CreateUpgradeHandler defines the function that creates an upgrade handler
CreateUpgradeHandler func(ModuleManager, module.Configurator, *AppKeepers) upgradetypes.UpgradeHandler
StoreUpgrades storetypes.StoreUpgrades
}
Upgrade defines a struct containing necessary fields that a SoftwareUpgradeProposal must have written, in order for the state migration to go smoothly. An upgrade must implement this struct, and then set it in the app.go. The app.go will then define the handler.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package evmparamsmigration contains the upgrade handler that migrates the x/vm module's on-chain Params from the v0.2.x proto layout to the v0.3.x layout.
|
Package evmparamsmigration contains the upgrade handler that migrates the x/vm module's on-chain Params from the v0.2.x proto layout to the v0.3.x layout. |
Click to show internal directories.
Click to hide internal directories.