chains

package
v0.0.15 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 3, 2026 License: MIT Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Chains added in v0.0.13

type Chains struct {
	// contains filtered or unexported fields
}

Chains manages chain clients by fetching chain configs periodically and adding/removing clients accordingly

func NewChains added in v0.0.13

func NewChains(
	pushCore *pushcore.Client,
	pushSigner *pushsigner.Signer,
	cfg *config.Config,
	logger zerolog.Logger,
) *Chains

NewChains creates a new chains manager

func (*Chains) GetClient added in v0.0.13

func (c *Chains) GetClient(chainID string) (common.ChainClient, error)

GetClient returns the chain client for the specified chain ID

func (*Chains) Start added in v0.0.13

func (c *Chains) Start(ctx context.Context) error

Start begins fetching chains and managing chain clients

func (*Chains) Stop added in v0.0.13

func (c *Chains) Stop()

Stop stops the chains manager

func (*Chains) StopAll added in v0.0.13

func (c *Chains) StopAll()

StopAll stops all chain clients

Directories

Path Synopsis
Package push provides a client for listening to Push Chain events.
Package push provides a client for listening to Push Chain events.

Jump to