Documentation
¶
Index ¶
- type Chains
- func (c *Chains) GetClient(chainID string) (common.ChainClient, error)
- func (c *Chains) GetStandardConfirmations(chainID string) uint64
- func (c *Chains) IsChainInboundEnabled(chainID string) bool
- func (c *Chains) IsChainOutboundEnabled(chainID string) bool
- func (c *Chains) IsEVMChain(chainID string) bool
- func (c *Chains) Start(ctx context.Context) error
- func (c *Chains) Stop()
- func (c *Chains) StopAll()
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Chains ¶
type Chains struct {
// contains filtered or unexported fields
}
Chains manages chain clients by fetching chain configs periodically and adding/removing clients accordingly
func NewChains ¶
func NewChains( pushCore *pushcore.Client, pushSigner *pushsigner.Signer, cfg *config.Config, logger zerolog.Logger, ) *Chains
NewChains creates a new chains manager
func (*Chains) GetClient ¶
func (c *Chains) GetClient(chainID string) (common.ChainClient, error)
GetClient returns the chain client for the specified chain ID
func (*Chains) GetStandardConfirmations ¶
GetStandardConfirmations returns the chain's standard block confirmations from registry config (BlockConfirmation.StandardInbound). Used for outbound tx completion. Returns 12 if not set.
func (*Chains) IsChainInboundEnabled ¶
IsChainInboundEnabled returns whether inbound is enabled for the given chain
func (*Chains) IsChainOutboundEnabled ¶
IsChainOutboundEnabled returns whether outbound is enabled for the given chain
func (*Chains) IsEVMChain ¶
IsEVMChain returns true if the chain uses EVM (e.g. Ethereum, BSC). Used by coordinator for nonce behaviour.