Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Chains ¶ added in v0.0.13
type Chains struct {
// contains filtered or unexported fields
}
Chains manages chain clients by fetching chain configs periodically and adding/removing clients accordingly
func NewChains ¶ added in v0.0.13
func NewChains( pushCore *pushcore.Client, pushSigner *pushsigner.Signer, cfg *config.Config, logger zerolog.Logger, ) *Chains
NewChains creates a new chains manager
func (*Chains) GetClient ¶ added in v0.0.13
func (c *Chains) GetClient(chainID string) (common.ChainClient, error)
GetClient returns the chain client for the specified chain ID
Click to show internal directories.
Click to hide internal directories.